Struct amazon_sp_vendor_direct_fulfillment_shipping::models::status_update_details::StatusUpdateDetails
source · [−]pub struct StatusUpdateDetails {
pub tracking_number: String,
pub status_code: String,
pub reason_code: String,
pub status_date_time: String,
pub status_location_address: Box<Address>,
pub shipment_schedule: Option<Box<StatusUpdateDetailsShipmentSchedule>>,
}Expand description
StatusUpdateDetails : Details for the shipment status update given by the vendor for the specific package.
Fields
tracking_number: StringThis is required to be provided for every package and should match with the trackingNumber sent for the shipment confirmation.
status_code: StringIndicates the shipment status code of the package that provides transportation information for Amazon tracking systems and ultimately for the final customer.
reason_code: StringProvides a reason code for the status of the package that will provide additional information about the transportation status.
status_date_time: StringThe date and time when the shipment status was updated. This field is expected to be in ISO-8601 date/time format, with UTC time zone or UTC offset. For example, 2020-07-16T23:00:00Z or 2020-07-16T23:00:00+01:00.
status_location_address: Box<Address>shipment_schedule: Option<Box<StatusUpdateDetailsShipmentSchedule>>Implementations